<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://orionorigin.com
 * @since      1.0.0
 *
 * @package    Vpc_Rqa
 * @subpackage Vpc_Rqa/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Vpc_Rqa
 * @subpackage Vpc_Rqa/admin
 * @author     orion <help@orionorigin.com>
 */
class Vpc_Rqa_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Rqa_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Rqa_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ( class_exists( 'vpc' ) ) {
			if ( is_vpc_admin_screen() ) {
				wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/vpc-rqa-admin.css', array(), VPC_RQA_VERSION, 'all' );
			}
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Rqa_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Rqa_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	}

	/**
	 * Runs the new version check and upgrade process
	 *
	 * @return \Vpc_Rqa_Updater
	 */
	public function get_updater() {
		if ( class_exists( 'vpc' ) ) {
			do_action( 'vpc_before_init_updater' );
			require_once VPC_RQA_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-rqa-updater.php';
			$updater = new Vpc_Rqa_Updater();
			$updater->init();
			require_once VPC_RQA_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-rqa-updating-manager.php';
			$updater->set_update_manager( new Vpc_Rqa_Updating_Manager( VPC_RQA_VERSION, $updater->version_url(), VPC_RQA_MAIN_FILE ) );
			do_action( 'vpc_after_init_updater' );
			return $updater;
		}
	}

	/**
	 * Function to add some request a quote settings.
	 *
	 * @param  array $skin_settings All VPC settings array.
	 * @return array                All VPC settings array.
	 */
	public function add_request_quote_settings( $skin_settings ) {
		$skin_settings[] = array(
			'type' => 'sectionbegin',
			'id'   => 'vpc-rqa-container',
		);
		$skin_settings[] = array(
			'title'   => __( 'Enable Request a quote option', 'vpc-rqa' ),
			'name'    => 'vpc-config[request-quote]',
			'type'    => 'radio',
			'options' => array(
				'Yes' => 'Yes',
				'No'  => 'No',
			),
			'default' => 'No',
			'class'   => 'view_option',
			'desc'    => __( 'Instead of adding the custom product to the cart, the customer will be able to request a quote. <a href=“https://orionorigin.com/guide/request-a-quote-add-on/” target=“_blank”>Learn more</a>.', 'vpc-rqa' ),
		);

		$skin_settings[] = array(
			'title'     => __( 'Enable cart addition', 'vpc-rqa' ),
			'name'      => 'vpc-config[add-to-cart]',
			'type'      => 'radio',
			'options'   => array(
				'Yes' => 'Yes',
				'No'  => 'No',
			),
			'default'   => 'No',
			'col_class' => 'vpc_rqa_conf_other_settings',
			'desc'      => __( 'Should the plugin show the add to cart button on the customization page when the ability to request a quote is enabled?', 'vpc-rqa' ),
		);

		$skin_settings[] = array(
			'title'     => __( 'Show customization price', 'vpc-rqa' ),
			'name'      => 'vpc-config[show-price]',
			'type'      => 'radio',
			'options'   => array(
				'Yes' => 'Yes',
				'No'  => 'No',
			),
			'default'   => 'No',
			'col_class' => 'vpc_rqa_conf_other_settings',
			'desc'      => __( 'Should the customization total price be visible when the ability to request a quote is enabled?', 'vpc-rqa' ),
		);

		$skin_settings[] = array(
			'title'     => __( 'Show the price of a configuration in the mail', 'vpc-rqa' ),
			'name'      => 'vpc-config[show-price-in-mail]',
			'type'      => 'radio',
			'options'   => array(
				'Yes' => 'Yes',
				'No'  => 'No',
			),
			'default'   => 'No',
			'col_class' => 'vpc_rqa_conf_other_settings',
			'desc'      => __( 'Should the plugin show the price of a configuration in the mail?', 'vpc-rqa' ),
		);

		$skin_settings[] = array(
			'title'     => __( 'Send a mail to the customer', 'vpc-rqa' ),
			'name'      => 'vpc-config[send-user-mail]',
			'type'      => 'radio',
			'options'   => array(
				'Yes' => 'Yes',
				'No'  => 'No',
			),
			'default'   => 'Yes',
			'col_class' => 'vpc_rqa_conf_other_settings',
			'desc'      => __( 'Should the plugin send a mail to customer ?', 'vpc-rqa' ),
		);

		if ( class_exists( 'Ofb' ) && class_exists( 'Vpc_Rqa' ) ) {
			global $wpdb;
			$ofb = array( 'default' => 'Default' );

			$resultats = $wpdb->get_results( "SELECT ID,post_title From {$wpdb->prefix}posts Where post_type = 'ofb' And post_status = 'publish'", OBJECT_K ); // phpcs:ignore
			if ( $resultats ) {
				foreach ( $resultats as $index => $data ) {
					$ofb[ $data->ID ] = $data->post_title;
				}
			}

			$skin_settings[] = array(
				'title'     => __( 'Select your form.', 'vpc-rqa' ),
				'name'      => 'vpc-config[form_selection]',
				'type'      => 'select',
				'options'   => $ofb,
				'default'   => 'default',
				'class'     => 'chosen_form',
				'col_class' => 'vpc_rqa_conf_other_settings',
				'desc'      => __( 'Select the form you want to display in your request a quote popup window.', 'vpc-rqa' ),
			);
		}
		$skin_settings[] = array( 'type' => 'sectionend' );
		return $skin_settings;
	}

	/**
	 * Function to add new global settings.
	 *
	 * @param  array $global_settings Global settings.
	 * @return array                  Global settings.
	 */
	public function add_global_settings( $global_settings ) {
		$begin = array(
			'type'  => 'sectionbegin',
			'id'    => 'vpc-email-container',
			'table' => 'options',
		);

		$license_key    = array(
			'title'   => __( 'Request a quote add on license key', 'vpc' ),
			'name'    => 'vpc-options[purchase-code-request-a-quote-add-on]',
			'type'    => 'text',
			'desc'    => __( 'This is the licence key you received after your purchase.<a href=“https://orionorigin.com/guide/how-to-add-my-license/” target=“_blank”>Learn more</a>. <a href=“https://orionorigin.com/my-account/orders/“ target=“blank”>Where can I find my license key</a>?', 'vpc' ),
			'default' => '',
		);
		$email_settings = array(
			'title'   => __( 'Recipients emails', 'vpc-rqa' ),
			'name'    => 'vpc-options[destinataire]',
			'type'    => 'text',
			'desc'    => __( 'Please separate each email with a comma e.g. adult@example.com, child@example4.com etc', 'vpc' ),
			'default' => '',
		);

		$mail_sender_name = array(
			'title'   => __( 'Mail sender\'s name', 'vpc-rqa' ),
			'name'    => 'vpc-options[sender_name]',
			'type'    => 'text',
			'desc'    => __( 'Enter a name for the mail sender field.', 'vpc-rqa' ),
			'default' => '',
		);

		$mail_title        = array(
			'title'   => __( "Mail's Title", 'vpc-rqa' ),
			'name'    => 'vpc-options[mail_title]',
			'type'    => 'text',
			'desc'    => __( "Mail's Title", 'vpc-rqa' ),
			'default' => '',
		);
		$mail_image_width  = array(
			'title' => __( 'Image width in mail', 'vpc-rqa' ),
			'name'  => 'vpc-options[rqa-image-width]',
			'type'  => 'number',
		);
		$mail_image_height = array(
			'title' => __( 'Image height in mail', 'vpc-rqa' ),
			'name'  => 'vpc-options[rqa-image-height]',
			'type'  => 'number',
		);
		$mail_image_size   = array(
			'title'   => __( 'Image size in mail', 'vpc-rqa' ),
			'name'    => 'vpc-options[rqa-image-size]',
			'type'    => 'groupedfields',
			'fields'  => array( $mail_image_width, $mail_image_height ),
			'default' => '',
			'desc'    => __( 'Set image size in mail.', 'vpc-rqa' ),
		);
		$add_captcha       = array(
			'title'   => __( 'Add Captcha ', 'vpc-rqa' ),
			'name'    => 'vpc-options[rqa-captcha]',
			'type'    => 'radio',
			'options' => array(
				'Yes' => 'Yes',
				'No'  => 'No',
			),
			'default' => 'No',
			'desc'    => __( 'Add Captcha on request a quote form.', 'vpc-rqa' ),
		);

		$end = array( 'type' => 'sectionend' );

		array_push( $global_settings, $begin );
		array_push( $global_settings, $license_key );
		array_push( $global_settings, $email_settings );
		array_push( $global_settings, $mail_sender_name );
		array_push( $global_settings, $mail_title );
		array_push( $global_settings, $mail_image_size );
		array_push( $global_settings, $add_captcha );
		array_push( $global_settings, $end );
		return $global_settings;
	}

}
