<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://orionorigin.com
 * @since      1.0.0
 *
 * @package    Vpc_Rqa
 * @subpackage Vpc_Rqa/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Vpc_Rqa
 * @subpackage Vpc_Rqa/includes
 * @author     orion <help@orionorigin.com>
 */
class Vpc_Rqa {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Vpc_Rqa_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'vpc-rqa';
		$this->version     = '1.0.0';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Vpc_Rqa_Loader. Orchestrates the hooks of the plugin.
	 * - Vpc_Rqa_I18n. Defines internationalization functionality.
	 * - Vpc_Rqa_Admin. Defines all hooks for the admin area.
	 * - Vpc_Rqa_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-vpc-rqa-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-vpc-rqa-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-vpc-rqa-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-vpc-rqa-public.php';

		$this->loader = new Vpc_Rqa_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Vpc_Rqa_I18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Vpc_Rqa_I18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Vpc_Rqa_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_filter( 'vpc_skins_settings', $plugin_admin, 'add_request_quote_settings' );
		$this->loader->add_filter( 'vpc_global_settings', $plugin_admin, 'add_global_settings' );
		$this->loader->add_action( 'init', $plugin_admin, 'get_updater' );

		$form_datas = new VPC_rqa_form_data( false );
		$this->loader->add_action( 'init', $form_datas, 'register_cpt_form_datas' );
		$this->loader->add_action( 'add_meta_boxes', $form_datas, 'get_form_datas_metabox' );
		$this->loader->add_action( 'admin_menu', $form_datas, 'disable_new_posts' );
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {
		$plugin_public = new Vpc_Rqa_Public( $this->get_plugin_name(), $this->get_version() );
		$this->loader->add_action( 'vpc_enqueue_core_styles', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'vpc_enqueue_core_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_filter( 'vpc_action_buttons', $plugin_public, 'add_buttons', 10, 2 );
		$this->loader->add_action( 'vpc_before_container', $plugin_public, 'add_modal_html_bloc', 10, 3 );
		$this->loader->add_filter( 'vpc_data', $plugin_public, 'add_data' );
		$this->loader->add_action( 'wp_ajax_save_form_datas', $plugin_public, 'save_form_datas' );
		$this->loader->add_action( 'wp_ajax_nopriv_save_form_datas', $plugin_public, 'save_form_datas' );

		$this->loader->add_action( 'wp_ajax_save_form_build_datas', $plugin_public, 'save_form_build_datas' );
		$this->loader->add_action( 'wp_ajax_nopriv_save_form_build_datas', $plugin_public, 'save_form_build_datas' );
		$this->loader->add_filter( 'wp_mail_content_type', $plugin_public, 'set_content_type' );
		$this->loader->add_filter( 'vpc_config_price_container', $plugin_public, 'display_price_container', 10, 2 );
		$this->loader->add_action( 'wp_ajax_save_vpc_rqa_canvas_img', $plugin_public, 'save_vpc_rqa_canvas_img' );
		$this->loader->add_action( 'wp_ajax_nopriv_save_vpc_rqa_canvas_img', $plugin_public, 'save_vpc_rqa_canvas_img' );
		$this->loader->add_action( 'wp_ajax_save_files', $plugin_public, 'save_ofb_files' );
		$this->loader->add_action( 'wp_ajax_nopriv_save_files', $plugin_public, 'save_ofb_files' );
		$this->loader->add_filter( 'wp_mail_from_name', $plugin_public, 'get_mail_sender_name' );
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Vpc_Rqa_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
