<?php
/**
 * The file that defines all the global functions
 *
 * @link       https://www.orionorigin.com/
 * @since      1.0.0
 *
 * @package    Vpc_Rqa
 * @subpackage Vpc_Rqa/includes
 */

/**
 * Function to get a view name.
 *
 * @param  string $sanitized_view_name A view's sanitized name.
 * @param  array  $config              Configuration's datas.
 * @return string                      A view's name.
 */
function vpc_rqa_get_view_name( $sanitized_view_name, $config ) {
	$views     = vpc_mva_get_config_views( $config );
	$view_name = '';
	if ( is_array( $views ) ) {
		foreach ( $views as $key => $view ) {
			if ( sanitize_title( $view ) === $sanitized_view_name ) {
				$view_name = $view;
			}
		}
	}
	return $view_name;
}

/**
 * Function to clean a configuration's recap.
 *
 * @param  array $dirty_recap Unclean configuration recap.
 * @return array              Clean configuration's recap.
 */
function vpc_rqa_clean_recap( $dirty_recap ) {
	$recap = array();
	if ( ! empty( $dirty_recap ) ) {
		$recap = $dirty_recap;
		if ( isset( $recap['action'] ) ) {
			unset( $recap['action'] );
		}
		if ( isset( $recap['nonce'] ) ) {
			unset( $recap['nonce'] );
		}
		if ( isset( $recap['id_ofb'] ) ) {
			unset( $recap['id_ofb'] );
		}

		foreach ( $dirty_recap as $key => $value ) {
			if ( '' === $value ) {
				unset( $recap[ $key ] );
				$text_properties = $key . ' properties';
				if ( isset( $recap[ $text_properties ] ) ) {
					unset( $recap[ $text_properties ] );
				}
			}
		}
	}
	return $recap;
}

/**
 * Function to sanitize an array.
 *
 * @param  array $data Unsanitized array.
 * @return array        Sanitized array.
 */
function vpc_rqa_sanitize_array( $data ) {
	if ( is_array( $data ) ) {
		foreach ( (array) $data as $k => $v ) {
			if ( is_array( $v ) ) {
				$data[ $k ] = vpc_rqa_sanitize_array( $v );
			} else {
				$data[ $k ] = sanitize_text_field( $v );
			}
		}
	} else {
		$data = sanitize_text_field( $data );
	}
	return $data;
}

/**
 * Get canvas datas recap.
 *
 * @param object $canvas_datas The canvas datas.
 */
function vpc_rqa_get_canvas_datas_recap( $canvas_datas ) {
	$configuration_options = '';
	if ( isset( $canvas_datas ) && is_object( $canvas_datas ) ) {
		foreach ( $canvas_datas as $key => $object ) {
			if ( isset( $object ) && is_object( $object ) ) {
				if ( isset( $object->type ) && ( 'text' === $object->type || 'group' === $object->type || 'textbox' === $object->type) ) {
					$text_component_id = $object->text_component_id;
					if ( 'group' === $object->type ) {
						if ( isset( $object->objects[1]->text ) && '' !== $object->objects[1]->text ) {
							$bg_html                = vpc_rqa_get_text_output_data( $text_component_id, $object->objects[1], $object->name );
							$configuration_options .= '<br>' . $bg_html;
						}
					} else {
						if ( isset( $object->text ) && '' !== $object->text ) {
							$bg_html                = vpc_rqa_get_text_output_data( $text_component_id, $object, $object->name );
							$configuration_options .= '<br>' . $bg_html;
						}
					}
				} elseif ( isset( $object ) && isset( $object->type ) && 'image' === $object->type ) {
					$upload_html            = "<img style='width:20%;padding-left:20px;' src='" . $object->src . "' />";
					$configuration_options .= '<br> ' . $object->name . ' ( ' . __( 'Upload component', 'vpc-rqa' ) . ' ) : ' . __( 'See details below', 'vpc-rqa' ) . '<br>' . $upload_html;
				}
			}
		}
	}
	return $configuration_options;
}

/**
 * Function to get the text output to render.
 *
 * @param  string $text_component_id   Text component data.
 * @param  object $object              A canvas's object.
 * @param  string $object_name         The object name.
 * @return string                      Text output.
 */
function vpc_rqa_get_text_output_data( $text_component_id, $object, $object_name ) {
	$text_component_data = vpc_cta_get_text_component_data( $text_component_id );
	$show_fonts          = ( isset( $text_component_data ) && isset( $text_component_data['show-fonts'] ) && '' !== $text_component_data['show-fonts'] ) ? $text_component_data['show-fonts'] : 'yes';
	$show_colors         = ( isset( $text_component_data ) && isset( $text_component_data['show-colors'] ) && '' !== $text_component_data['show-colors'] ) ? $text_component_data['show-colors'] : 'yes';
	$hex_and_opacity     = vpc_cta_convert_rgb_to_hex( $object->fill );
	$bg_html             = ' ' . $object_name . ' ( ' . __( 'Text component', 'vpc-rqa' ) . ' ) : ' . __( 'See details below', 'vpc-rqa' ) . '<br> <span style="padding-left:20px;"> - ' . __( 'Text', 'vpc-rqa' ) . ' : ' . $object->text . '</span><br> <span style="padding-left:20px;"> - ' . __( 'Font size', 'vpc-rqa' ) . ' : ' . $object->fontSize . 'px</span><br>'; // phpcs:ignore
	if ( isset( $show_fonts ) && isset( $show_colors ) && 'yes' === $show_fonts && 'yes' === $show_colors ) {
		$bg_html .= ' <span style="padding-left:20px;"> - ' . __( 'Color', 'vpc-rqa' ) . ' : ' . $object->color_name . '</span><br> <span style="padding-left:20px;"> - ' . __( 'Font family', 'vpc-rqa' ) . ' : ' . $object->fontFamily . '</span><br>'; // phpcs:ignore
	} elseif ( isset( $show_fonts ) && isset( $show_colors ) && 'yes' === $show_fonts && 'yes' !== $show_colors ) {
		$bg_html .= ' <span style="padding-left:20px;"> - ' . __( 'Font family', 'vpc-rqa' ) . ' : ' . $object->fontFamily . '</span><br>'; // phpcs:ignore
	} elseif ( isset( $show_fonts ) && isset( $show_colors ) && 'yes' === $show_colors && 'yes' !== $show_fonts ) {
		$bg_html .= ' <span style="padding-left:20px;"> - ' . __( 'Color', 'vpc-rqa' ) . ' : ' . $object->color_name . '</span><br>';
	}
	return $bg_html;
}

/**
 * Function to get canvas recap to save.
 *
 * @param  array $recap         Configurator recap datas.
 * @param  array $canvas_datas  A canvas's object.
 * @return string               Text output.
 */
function vpc_rqa_get_canvas_recap_to_save( $recap, $canvas_datas ) {
	if ( isset( $canvas_datas ) && is_object( $canvas_datas ) ) {
		foreach ( $canvas_datas as $key => $object ) {
			if ( isset( $object ) && is_object( $object ) ) {
				if ( isset( $object->type ) && ( 'text' === $object->type || 'group' === $object->type ) ) {
					$object_name       = $object->name . ' ( ' . __( 'Text component', 'vpc-rqa' ) . ' ) ';
					$text_component_id = $object->text_component_id;
					if ( 'group' === $object->type ) {
						if ( isset( $object->objects[1]->text ) && '' !== $object->objects[1]->text ) {
							$recap[ $object_name ] = vpc_rqa_add_data_into_recap( $text_component_id, $object->objects[1] );
						}
					} else {
						if ( isset( $object->text ) && '' !== $object->text ) {
							$recap[ $object_name ] = vpc_rqa_add_data_into_recap( $text_component_id, $object );
						}
					}
				} elseif ( isset( $object ) && isset( $object->type ) && 'image' === $object->type ) {
					$object_name           = $object->name . ' ( ' . __( 'Upload component', 'vpc-rqa' ) . ' ) ';
					$recap[ $object_name ] = $object->src;
				}
			}
		}
	}
	return $recap;
}

/**
 * Function to add canvas data into recap.
 *
 * @param  string $text_component_id   Text component data.
 * @param  object $object              A canvas's object.
 * @return string                      Text output.
 */
function vpc_rqa_add_data_into_recap( $text_component_id, $object ) {
	$text_component_data = vpc_cta_get_text_component_data( $text_component_id );
	$show_fonts          = ( isset( $text_component_data ) && isset( $text_component_data['show-fonts'] ) && '' !== $text_component_data['show-fonts'] ) ? $text_component_data['show-fonts'] : 'yes';
	$show_colors         = ( isset( $text_component_data ) && isset( $text_component_data['show-colors'] ) && '' !== $text_component_data['show-colors'] ) ? $text_component_data['show-colors'] : 'yes';
	$hex_and_opacity     = vpc_cta_convert_rgb_to_hex( $object->fill );
	$bg_html             = __( 'Text', 'vpc-rqa' ) . ' : ' . $object->text . ' | ' . __( 'Font size', 'vpc-rqa' ) . ' : ' . $object->fontSize . 'px'; // phpcs:ignore
	if ( isset( $show_fonts ) && isset( $show_colors ) && 'yes' === $show_fonts && 'yes' === $show_colors ) {
		$bg_html .= ' | ' . __( 'Color', 'vpc-rqa' ) . ' : ' . $object->color_name . ' | ' . __( 'Font family', 'vpc-rqa' ) . ' : ' . $object->fontFamily; // phpcs:ignore
	} elseif ( isset( $show_fonts ) && isset( $show_colors ) && 'yes' === $show_fonts && 'yes' !== $show_colors ) {
		$bg_html .= ' | ' . __( 'Font family', 'vpc-rqa' ) . ' : ' . $object->fontFamily; // phpcs:ignore
	} elseif ( isset( $show_fonts ) && isset( $show_colors ) && 'yes' === $show_colors && 'yes' !== $show_fonts ) {
		$bg_html .= ' | ' . __( 'Color', 'vpc-rqa' ) . ' : ' . $object->color_name;
	}
	return $bg_html;
}

/**
 * Function to create captcha.
 */
function create_captcha() {
	$digit1 = wp_rand( 1, 20 );
	$digit2 = wp_rand( 1, 20 );
	if ( wp_rand( 0, 1 ) === 1 ) {
		$math          = "$digit1 + $digit2";
		$captcha_total = (int) $digit1 + (int) $digit2;
	} else {
		$math          = "$digit1 - $digit2";
		$captcha_total = (int) $digit1 - (int) $digit2;
	}
	return array(
		'captcha' => $math,
		'result'  => $captcha_total,
	);
}
/**
 * Function to load allowed lsd tags in order to properly escape outputs.
 *
 * @return array
 */
function vpc_rqa_get_allowed_tags() {
	$allowed_tags = wp_kses_allowed_html( 'post' );

	$allowed_tags['a'] = array(
		'href'  => array(),
		'id'    => array(),
		'class' => array(),
	);
	return $allowed_tags;
}
